Print sassy match data frames
Arguments
- x
A
sassy_matchesdata frame.- ...
Ignored; accepted for compatibility with
print().- color
If
TRUE, colormatch_regionby CIGAR operation with ANSI escape sequences: green matches, orange substitutions, blue inserted text, and red gaps for pattern bases absent from the text. Defaults togetOption("Rsassy.coloring", FALSE).